@@ -1,4 +1,4 @@
-use libc::{c_char, c_int, c_long};
+use libc::{c_char, c_int, c_long, c_uchar};
 use object::PyObject;
 
 #[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
@@ -66,7 +66,21 @@ pub unsafe fn PyImport_ImportModuleEx(name: *const c_char,
     // pub static mut PyNullImporter_Type: PyTypeObject; -- does not actually exist in shared library
 
     pub fn PyImport_AppendInittab(name: *const c_char,
-                                  initfunc: Option<extern "C" fn() -> *mut PyObject>)
+                                  initfunc: Option<unsafe extern "C" fn() -> *mut PyObject>)
      -> c_int;
 }
 
+#[repr(C)]
+#[derive(Copy, Clone)]
+#[cfg(not(Py_LIMITED_API))]
+pub struct _frozen {
+    pub name: *const c_char,
+    pub code: *const c_uchar,
+    pub size: c_int,
+}
+
+#[cfg(not(Py_LIMITED_API))]
+#[cfg_attr(windows, link(name="pythonXY"))]
+extern "C" {
+    pub static mut PyImport_FrozenModules: *const _frozen;
+}
