@@ -72,7 +72,7 @@ impl Default for PyObjectArenaAllocator {
 /// Test if a type has a GC head
 #[inline(always)]
 pub unsafe fn PyType_IS_GC(t : *mut PyTypeObject) -> c_int {
-    PyType_HasFeature((t), Py_TPFLAGS_HAVE_GC)
+    PyType_HasFeature(t, Py_TPFLAGS_HAVE_GC)
 }
 
 /// Test if an object has a GC head
