@@ -6,6 +6,8 @@ use pystate::PyThreadState;
 use pyarena::PyArena;
 
 #[cfg_attr(windows, link(name="pythonXY"))] extern "C" { // TODO: these moved to pylifecycle.h
+    #[cfg(Py_3_4)]
+    pub fn Py_SetStandardStreamEncoding(encoding: *const c_char, errors: *const c_char) -> c_int;
     pub fn Py_SetProgramName(arg1: *const wchar_t) -> ();
     pub fn Py_GetProgramName() -> *mut wchar_t;
     pub fn Py_SetPythonHome(arg1: *const wchar_t) -> ();
@@ -13,6 +15,8 @@ use pyarena::PyArena;
     pub fn Py_Initialize() -> ();
     pub fn Py_InitializeEx(arg1: c_int) -> ();
     pub fn Py_Finalize() -> ();
+    #[cfg(Py_3_6)]
+    pub fn Py_FinalizeEx() -> c_int;
     pub fn Py_IsInitialized() -> c_int;
     pub fn Py_NewInterpreter() -> *mut PyThreadState;
     pub fn Py_EndInterpreter(arg1: *mut PyThreadState) -> ();
@@ -24,7 +28,7 @@ use pyarena::PyArena;
 #[derive(Copy, Clone)]
 #[cfg(not(Py_LIMITED_API))]
 pub struct PyCompilerFlags {
-    cf_flags : c_int
+    pub cf_flags : c_int
 }
 
 #[cfg(not(Py_LIMITED_API))]
