@@ -1,7 +1,7 @@
 use libc::c_int;
 use object::*;
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyTraceBack_Here(arg1: *mut ::PyFrameObject) -> c_int;
     pub fn PyTraceBack_Print(arg1: *mut PyObject, arg2: *mut PyObject)
      -> c_int;
